==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-volume/translations/volume_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Ativar/desativar som</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Controle de Volume: Os seguintes atalhos não podem ser registrados: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>Volume: %1%%2</source>
        <translation>Volume: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>(muted)</source>
        <translation>(mudo)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Configurações de controle de volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Dispositivo de controle</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Mudo no clique do meio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Exibir no clique do mouse</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permitir volume além de 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>Sempre notificar sobre alterações de volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="91"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Notificar sobre alterações de volume com o teclado</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="106"/>
        <source>Volume adjust step</source>
        <translation>Passos de ajuste do volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="125"/>
        <source>External Mixer</source>
        <translation>Mixer externo</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>Executar Mixer</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;xer</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-volume/translations/volume_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Ativar/desativar som</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Controle de Volume: Os seguintes atalhos não podem ser registrados: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>Volume: %1%%2</source>
        <translation>Volume: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>(muted)</source>
        <translation>(mudo)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Configurações de controle de volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Dispositivo de controle</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>Pulseaudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Mudo no clique do meio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>Exibir no clique do mouse</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permitir volume além de 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>Sempre notificar sobre alterações de volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="91"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Notificar sobre alterações de volume com o teclado</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="106"/>
        <source>Volume adjust step</source>
        <translation>Passos de ajuste do volume</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="125"/>
        <source>External Mixer</source>
        <translation>Mixador externo</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Launch mixer</source>
        <translation>Executar Mixador</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="56"/>
        <source>Mi&amp;xer</source>
        <translation>Mi&amp;xador</translation>
    </message>
</context>
</TS>
